summaryrefslogtreecommitdiff
path: root/vcl/inc
diff options
context:
space:
mode:
authorJan Holesovsky <kendy@suse.cz>2013-06-14 16:33:23 +0200
committerJan Holesovsky <kendy@suse.cz>2013-06-15 14:42:09 +0200
commitedbca87dea4d7ab7c70039579f90c6d22e076b1b (patch)
tree1ad4b4e8cfb08e21bc4bb79e21fa3fa4cd6ee580 /vcl/inc
parent468841be44071be8e8442b7bce13ef65b20396f0 (diff)
widget layout: Allow specification of size request for toolbox items.
Change-Id: I4b2f1ca9eb0b5bdb77e16a969918dd4f6afefb53
Diffstat (limited to 'vcl/inc')
-rw-r--r--vcl/inc/toolbox.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/vcl/inc/toolbox.h b/vcl/inc/toolbox.h
index 6a00fadf6d07..8670aeeb101b 100644
--- a/vcl/inc/toolbox.h
+++ b/vcl/inc/toolbox.h
@@ -63,7 +63,9 @@ struct ImplToolItem
OString maHelpId;
Rectangle maRect;
Rectangle maCalcRect;
- // the overall horizontal item size, including one or more of [image size + textlength + dropdown arrow]
+ /// Widget layout may request size; set it as the minimal size.
+ Size maMinimalItemSize;
+ /// The overall horizontal item size, including one or more of [image size + textlength + dropdown arrow]
Size maItemSize;
long mnSepSize;
long mnDropDownArrowWidth;